Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsRegistered ¶
IsRegistered returns true iff the named module is registered.
Types ¶
type Info ¶
type Info struct {
Name string // The module name
Description string // A brief description of the module
URL string // A url for further documentation
Load LoadFunc // The function that creates and returns the module
Preload bool // Is the module pre-loaded?
Requires []string // Ensure that the given modules are loaded first. Note that circular requirements are not protected against.
}
Info is used to register a module.
func GetInfo ¶
GetInfo returns returns the Info for the given module. The second return value will be false iff the module is not registered.
func Registered ¶
func Registered() []Info
Registered returns a slice of of all currently registered modules.
Click to show internal directories.
Click to hide internal directories.